@@ -219,11 +219,11 @@ void KKameraConfig::load(void)
 			qCDebug(KAMERA_KCONTROL) << "Loading configuration for serial port camera: "
                                      << *it;
 			kcamera = new KCamera(*it, cg.readEntry("Path"));
-			connect(kcamera, qOverload<const QString&>(&KCamera::error), 
-				this, qOverload<const QString&>(&KKameraConfig::slot_error));
+            connect(kcamera, qOverload<const QString&>(&KCamera::error),
+                this, qOverload<const QString&>(&KKameraConfig::slot_error));
 
-			connect(kcamera, qOverload<const QString&, const QString&>(&KCamera::error), 
-				this, qOverload<const QString&, const QString&>(&KKameraConfig::slot_error));
+            connect(kcamera, qOverload<const QString&, const QString&>(&KCamera::error),
+                this, qOverload<const QString&, const QString&>(&KKameraConfig::slot_error));
 
 			kcamera->load(m_config);
 			m_devices[*it] = kcamera;
@@ -266,11 +266,11 @@ void KKameraConfig::load(void)
 
 		kcamera = new KCamera(portit.value(), portit.key());
 
-		connect(kcamera, qOverload<const QString&>(&KCamera::error), 
-			this, qOverload<const QString&>(&KKameraConfig::slot_error));
+        connect(kcamera, qOverload<const QString&>(&KCamera::error),
+            this, qOverload<const QString&>(&KKameraConfig::slot_error));
 
-		connect(kcamera, qOverload<const QString&, const QString&>(&KCamera::error), 
-			this, qOverload<const QString&, const QString&>(&KKameraConfig::slot_error));
+        connect(kcamera, qOverload<const QString&, const QString&>(&KCamera::error),
+            this, qOverload<const QString&, const QString&>(&KKameraConfig::slot_error));
 
 		m_devices[portit.value()] = kcamera;
 	}
@@ -308,15 +308,15 @@ void KKameraConfig::afterCameraOperation()
 
 QString KKameraConfig::suggestName(const QString &name)
 {
-	QString new_name = name;
-	new_name.remove('/'); // we cannot have a slash in a URI's host
+    QString new_name = name;
+    new_name.remove(QLatin1Char('/')); // we cannot have a slash in a URI's host
 
 	if (!m_devices.contains(new_name)) return new_name;
 
 	// try new names with a number appended until we find a free one
 	int i = 1;
-	while (i++ < 0xffff) {
-		new_name = name + " (" + QString::number(i) + ')';
+    while (i++ < 0xffff) {
+        new_name = name + QStringLiteral(" (") + QString::number(i) + QLatin1Char(')');
 		if (!m_devices.contains(new_name)) return new_name;
 	}
 
@@ -326,7 +326,7 @@ QString KKameraConfig::suggestName(const QString &name)
 void KKameraConfig::slot_addCamera()
 {
         KCamera *m_device = new KCamera(QString(), QString());
-        connect(m_device, qOverload<const QString&>(&KCamera::error),
+    connect(m_device, qOverload<const QString&>(&KCamera::error),
                 this, qOverload<const QString&>(&KKameraConfig::slot_error));
 
         connect(m_device, qOverload<const QString&, const QString&>(&KCamera::error),
@@ -338,7 +338,7 @@ void KKameraConfig::slot_addCamera()
 		m_device->setName(suggestName(m_device->model()));
 		m_devices.insert(m_device->name(), m_device);
 		populateDeviceListView();
-		emit changed(true);
+        Q_EMIT changed(true);
 	} else {
 		delete m_device;
 	}
@@ -353,7 +353,7 @@ void KKameraConfig::slot_removeCamera()
 		delete m_device;
 		m_config->deleteGroup(name);
 		populateDeviceListView();
-		emit changed(true);
+        Q_EMIT changed(true);
 	}
 }
 
