@@ -54,7 +54,7 @@ extern "C" {
 static const int INDEX_NONE= 0;
 static const int INDEX_SERIAL = 1;
 static const int INDEX_USB= 2;
-static GPContext *glob_context = 0;
+static GPContext *glob_context = nullptr;
 
 #ifdef DEBUG
 static void gp_errordumper(GPLogLevel level, const char *domain, const char *str, void *data) {
@@ -90,17 +90,17 @@ bool KCamera::initInformation()
     }
 
     if(gp_abilities_list_new(&m_abilitylist) != GP_OK) {
-        emit error(i18n("Could not allocate memory for the abilities list."));
+        Q_EMIT error(i18n("Could not allocate memory for the abilities list."));
         return false;
     }
     if(gp_abilities_list_load(m_abilitylist, glob_context) != GP_OK) {
-        emit error(i18n("Could not load ability list."));
+        Q_EMIT error(i18n("Could not load ability list."));
         return false;
     }
     int index = gp_abilities_list_lookup_model(m_abilitylist,
                                                m_model.toLocal8Bit().data());
     if(index < 0) {
-        emit error(i18n("Description of abilities for camera %1 is not available."
+        Q_EMIT error(i18n("Description of abilities for camera %1 is not available."
                     " Configuration options may be incorrect.", m_model));
         return false;
     }
@@ -124,7 +124,7 @@ bool KCamera::initCamera()
         result = gp_camera_new(&m_camera);
         if (result != GP_OK) {
             // m_camera is not initialized, so we cannot get result as string
-            emit error(i18n("Could not access driver. Check your gPhoto2 installation."));
+            Q_EMIT error(i18n("Could not access driver. Check your gPhoto2 installation."));
             return false;
         }
 
@@ -143,7 +143,7 @@ bool KCamera::initCamera()
         if (result != GP_OK) {
             gp_camera_free(m_camera);
             m_camera = NULL;
-            emit error(
+            Q_EMIT error(
                 i18n("Unable to initialize camera. Check your port settings and camera connectivity and try again."),
                 QString::fromLocal8Bit(gp_result_as_string(result)));
             return false;
@@ -182,7 +182,7 @@ bool KCamera::configure()
 
     result = gp_camera_get_config(m_camera, &window, glob_context);
     if (result != GP_OK) {
-        emit error(i18n("Camera configuration failed."),
+        Q_EMIT error(i18n("Camera configuration failed."),
                 QString::fromLocal8Bit(gp_result_as_string(result)));
         return false;
     }
@@ -193,7 +193,7 @@ bool KCamera::configure()
     if (result == GP_PROMPT_OK) {
         result = gp_camera_set_config(m_camera, window, glob_context);
         if (result != GP_OK) {
-            emit error(i18n("Camera configuration failed."),
+            Q_EMIT error(i18n("Camera configuration failed."),
                     QString::fromLocal8Bit(gp_result_as_string(result)));
             return false;
         }
@@ -231,8 +231,8 @@ void KCamera::save(KConfig *config)
 QString KCamera::portName()
 {
     const QString port = m_path.left(m_path.indexOf(QLatin1Char(':'))).toLower();
-    if (port == "serial") return i18n("Serial");
-    if (port == "usb") return i18n("USB");
+    if (port == QStringLiteral("serial")) return i18n("Serial");
+    if (port == QStringLiteral("usb")) return i18n("USB");
     return i18n("Unknown port");
 }
 
@@ -278,10 +278,10 @@ QStringList KCamera::supportedPorts()
     initInformation();
     QStringList ports;
     if (m_abilities.port & GP_PORT_SERIAL) {
-        ports.append(QLatin1String("serial"));
+        ports.append(QStringLiteral("serial"));
     }
     if (m_abilities.port & GP_PORT_USB) {
-        ports.append(QLatin1String("usb"));
+        ports.append(QStringLiteral("usb"));
     }
     return ports;
 }
@@ -301,10 +301,10 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
     setModal( true );
     m_device = device;
     connect(m_device, qOverload<const QString&>(&KCamera::error),
-		this, qOverload<const QString&>(&KameraDeviceSelectDialog::slot_error));
+        this, qOverload<const QString&>(&KameraDeviceSelectDialog::slot_error));
 
     connect(m_device, qOverload<const QString&, const QString&>(&KCamera::error),
-		this, qOverload<const QString&, const QString&>(&KameraDeviceSelectDialog::slot_error));
+        this, qOverload<const QString&, const QString&>(&KameraDeviceSelectDialog::slot_error));
 
     QWidget *page = new QWidget( this );
 
@@ -482,9 +482,9 @@ void KameraDeviceSelectDialog::save()
     m_device->setModel(m_modelSel->currentIndex().data(Qt::DisplayRole).toString());
 
     if (m_serialRB->isChecked()) {
-        m_device->setPath("serial:" + m_serialPortCombo->currentText());
+        m_device->setPath(QStringLiteral("serial:") + m_serialPortCombo->currentText());
     } else if ( m_USBRB->isChecked() ) {
-        m_device->setPath("usb:");
+        m_device->setPath(QStringLiteral("usb:"));
     }
 }
 
@@ -499,8 +499,8 @@ void KameraDeviceSelectDialog::load()
         setPortType(INDEX_USB);
     }
 
-    QList<QStandardItem *> items = m_model->findItems(m_device->model());
-    foreach (QStandardItem *item, items) {
+    const QList<QStandardItem *> items = m_model->findItems(m_device->model());
+    for (QStandardItem *item : items) {
         const QModelIndex index = m_model->indexFromItem(item);
         m_modelSel->selectionModel()->select(index, QItemSelectionModel::Select);
     }
